@@ -1,4 +1,4 @@
-//@line 40 "/usr/ports/pobj/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/history-panel.js"
+//@line 40 "/usr/obj/i386/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/history-panel.js"
 
 var gHistoryTree;
 var gSearchBox;
@@ -23,35 +23,16 @@ function HistorySidebarInit()
     document.getElementById("bydayandsite").setAttribute("checked", "true");
   else
     document.getElementById("byday").setAttribute("checked", "true");
-
-  initContextMenu();
   
   searchHistory("");
 }
 
-function initContextMenu() {
-  // Insert "Bookmark This Link" right before the copy item
-  document.getElementById("placesContext")
-          .insertBefore(document.getElementById("addBookmarkContextItem"),
-                        document.getElementById("placesContext_copy"));
-}
-
 function GroupBy(groupingType)
 {
   gHistoryGrouping = groupingType;
   searchHistory(gSearchBox.value);
 }
 
-function historyAddBookmarks()
-{ 
-  // no need to check gHistoryTree.view.selection.count
-  // node will be null if there is a multiple selection 
-  // or if the selected item is not a URI node
-  var node = gHistoryTree.selectedNode;
-  if (node && PlacesUtils.nodeIsURI(node))
-    PlacesUIUtils.showMinimalAddBookmarkUI(PlacesUtils._uri(node.uri), node.title);
-}
-
 function searchHistory(aInput)
 {
   var query = PlacesUtils.history.getNewQuery();
