@@ -43,6 +43,15 @@ var PlacesOrganizer = {
   _places: null,
   _content: null,
 
+  // IDs of fields from editBookmarkOverlay that should be hidden when infoBox
+  // is minimal. IDs should be kept in sync with the IDs of the elements
+  // observing additionalInfoBroadcaster.
+  _additionalInfoFields: [
+    "editBMPanel_descriptionRow",
+    "editBMPanel_loadInSidebarCheckbox",
+    "editBMPanel_keywordRow",
+  ],
+
   _initFolderTree: function() {
     var leftPaneRoot = PlacesUIUtils.leftPaneFolderId;
     this._places.place = "place:excludeItems=1&expandQueries=0&folder=" + leftPaneRoot;
@@ -79,10 +88,10 @@ var PlacesOrganizer = {
     // Set up the search UI.
     PlacesSearchBox.init();
 
-//@line 86 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 95 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
 
     window.addEventListener("AppCommand", this, true);
-//@line 109 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 118 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
 
     // remove the "Properties" context-menu item, we've our own details pane
     document.getElementById("placesContext")
@@ -582,6 +591,7 @@ var PlacesOrganizer = {
     var infoBox = document.getElementById("infoBox");
     var infoBoxExpander = document.getElementById("infoBoxExpander");
     var infoBoxExpanderWrapper = document.getElementById("infoBoxExpanderWrapper");
+    var additionalInfoBroadcaster = document.getElementById("additionalInfoBroadcaster");
 
     if (!aNode) {
       infoBoxExpanderWrapper.hidden = true;
@@ -600,8 +610,11 @@ var PlacesOrganizer = {
       if (infoBox.getAttribute("wasminimal") == "true")
         infoBox.setAttribute("minimal", "true");
       infoBox.removeAttribute("wasminimal");
-      infoBoxExpanderWrapper.hidden = false;
+      infoBoxExpanderWrapper.hidden =
+        this._additionalInfoFields.every(function (id)
+          document.getElementById(id).collapsed);
     }
+    additionalInfoBroadcaster.hidden = infoBox.getAttribute("minimal") == "true";
   },
 
   // NOT YET USED
@@ -638,9 +651,16 @@ var PlacesOrganizer = {
 
       // don't update the panel if we are already editing this node unless we're
       // in multi-edit mode
-      if (aSelectedNode && gEditItemOverlay.itemId == aSelectedNode.itemId &&
-          detailsDeck.selectedIndex == 1 && !gEditItemOverlay.multiEdit)
-        return;
+      if (aSelectedNode) {
+        var concreteId = PlacesUtils.getConcreteItemId(aSelectedNode);
+        var nodeIsSame = gEditItemOverlay.itemId == aSelectedNode.itemId ||
+                         gEditItemOverlay.itemId == concreteId ||
+                         (aSelectedNode.itemId == -1 && gEditItemOverlay.uri &&
+                          gEditItemOverlay.uri == aSelectedNode.uri);
+        if (nodeIsSame && detailsDeck.selectedIndex == 1 &&
+            !gEditItemOverlay.multiEdit)
+          return;
+      }
     }
 
     // Clean up the panel before initing it again.
@@ -758,18 +778,21 @@ var PlacesOrganizer = {
     var infoBox = document.getElementById("infoBox");
     var infoBoxExpander = document.getElementById("infoBoxExpander");
     var infoBoxExpanderLabel = document.getElementById("infoBoxExpanderLabel");
+    var additionalInfoBroadcaster = document.getElementById("additionalInfoBroadcaster");
 
     if (infoBox.getAttribute("minimal") == "true") {
       infoBox.removeAttribute("minimal");
       infoBoxExpanderLabel.value = infoBoxExpanderLabel.getAttribute("lesslabel");
       infoBoxExpanderLabel.accessKey = infoBoxExpanderLabel.getAttribute("lessaccesskey");
       infoBoxExpander.className = "expander-up";
+      additionalInfoBroadcaster.removeAttribute("hidden");
     }
     else {
       infoBox.setAttribute("minimal", "true");
       infoBoxExpanderLabel.value = infoBoxExpanderLabel.getAttribute("morelabel");
       infoBoxExpanderLabel.accessKey = infoBoxExpanderLabel.getAttribute("moreaccesskey");
       infoBoxExpander.className = "expander-down";
+      additionalInfoBroadcaster.setAttribute("hidden", "true");
     }
   },
 
@@ -781,9 +804,9 @@ var PlacesOrganizer = {
     // If the advanced query builder is showing, use that.
     var options = this.getCurrentOptions();
 
-//@line 810 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 833 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
     var queries = this.getCurrentQueries();
-//@line 812 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 835 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
 
     var placeSpec = PlacesUtils.history.queriesToQueryString(queries,
                                                              queries.length,
@@ -988,7 +1011,7 @@ var PlacesSearchBox = {
     var searchModifiers = document.getElementById("searchModifiers");
     searchModifiers.hidden = false;
 
-//@line 1021 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 1044 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
   },
 
   hideSearchUI: function PSB_hideSearchUI() {
@@ -1005,7 +1028,7 @@ var PlacesQueryBuilder = {
   queries: [],
   queryOptions: null,
 
-//@line 1500 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/browser/components/places/content/places.js"
+//@line 1523 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/places/content/places.js"
 
   /**
    * Called when a scope button in the scope bar is clicked.
