@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/advanced.js"
+//@line 39 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -23,8 +23,9 @@ var gAdvancedPane = {
         advancedPrefs.selectedIndex = preference.value;
     }
 
-//@line 68 "/usr/obj/i386/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/advanced.js"
+//@line 68 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
+//@line 72 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
   },
 
   /**
@@ -98,6 +99,35 @@ var gAdvancedPane = {
     return checkbox.checked ? (this._storedSpellCheck == 2 ? 2 : 1) : 0;
   },
 
+  /**
+   *
+   */
+  initSubmitCrashes: function ()
+  {
+    var checkbox = document.getElementById("submitCrashesBox");
+    try {
+      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
+               getService(Components.interfaces.nsICrashReporter_MOZILLA_1_9_2_BRANCH);
+      checkbox.checked = cr.submitReports;
+    } catch (e) {
+      checkbox.style.display = "none";
+    }
+  },
+
+  /**
+   *
+   */
+  updateSubmitCrashes: function ()
+  {
+    var checkbox = document.getElementById("submitCrashesBox");
+    try {
+      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
+               getService(Components.interfaces.nsICrashReporter);
+      cr.submitReports = checkbox.checked;
+    } catch (e) { }
+  },
+
+
   // NETWORK TAB
 
   /*
@@ -357,7 +387,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 499 "/usr/obj/i386/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/advanced.js"
+//@line 531 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -427,7 +457,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 569 "/usr/obj/i386/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/advanced.js"
+//@line 601 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -473,5 +503,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 615 "/usr/obj/i386/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/advanced.js"
+//@line 647 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/advanced.js"
 };
