@@ -1,5 +1,5 @@
 /*
-//@line 42 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/browser/components/preferences/privacy.js"
+//@line 42 "/usr/obj/i386/firefox36-3.6.18/mozilla-1.9.2/browser/components/preferences/privacy.js"
 */
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
@@ -494,6 +494,7 @@ var gPrivacyPane = {
                                            "", null);
   },
 
+
   /**
    * Displays a dialog from which individual parts of private data may be
    * cleared.
@@ -508,7 +509,7 @@ var gPrivacyPane = {
     const Cc = Components.classes, Ci = Components.interfaces;
     var glue = Cc["@mozilla.org/browser/browserglue;1"]
                  .getService(Ci.nsIBrowserGlue);
-    glue.sanitize(window || null);
+    glue.sanitize(window);
 
     // reset the timeSpan pref
     if (aClearEverything)
@@ -519,8 +520,7 @@ var gPrivacyPane = {
    * Enables or disables the "Settings..." button depending
    * on the privacy.sanitize.sanitizeOnShutdown preference value
    */
-  _updateSanitizeSettingsButton: function ()
-   {
+  _updateSanitizeSettingsButton: function () {
     var settingsButton = document.getElementById("clearDataSettings");
     var sanitizeOnShutdownPref = document.getElementById("privacy.sanitize.sanitizeOnShutdown");
     
