@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/toolkit/components/cookie/content/cookieAcceptDialog.js"
+//@line 37 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/toolkit/components/cookie/content/cookieAcceptDialog.js"
 
 const nsICookieAcceptDialog = Components.interfaces.nsICookieAcceptDialog;
 const nsIDialogParamBlock = Components.interfaces.nsIDialogParamBlock;
@@ -196,5 +196,5 @@ function GetExpiresString(secondsUntilExpires) {
     }
     return expiry;
   }
-  return cookieBundle.getString("atEndOfSession");
+  return cookieBundle.getString("expireAtEndOfSession");
 }
