@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/usr/obj/i386/firefox36-3.6.18/mozilla-1.9.2/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -53,7 +53,7 @@ var InlineSpellCheckerUI = {
     if (spellsel.rangeCount == 0)
       return; // easy case - no misspellings
 
-    var range = this.mInlineSpellChecker.getMispelledWord(rangeParent,
+    var range = this.mInlineSpellChecker.getMisspelledWord(rangeParent,
                                                           rangeOffset);
     if (! range)
       return; // not over a misspelled word
