@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/firefox35-3.5.19/mozilla-1.9.1/toolkit/components/viewsource/content/viewSourceUtils.js"
+//@line 38 "/usr/ports/pobj/firefox36-3.6.18/mozilla-1.9.2/toolkit/components/viewsource/content/viewSourceUtils.js"
 
 /*
  * To keep the global namespace safe, don't define global variables and 
@@ -99,9 +99,13 @@ var gViewSourceUtils = {
                     .getService(Components.interfaces.nsPIExternalAppLauncher)
                     .deleteTemporaryFileOnExit(file);
         } else {
-          // we'll use nsIWebPageDescriptor to get the source because it may not have to refetch
-          // the file from the server
-          var webShell = Components.classes["@mozilla.org/webshell;1"].createInstance();
+          // we'll use nsIWebPageDescriptor to get the source because it may
+          // not have to refetch the file from the server
+          // XXXbz this is so broken...  This code doesn't set up this docshell
+          // at all correctly; if somehow the view-source stuff managed to
+          // execute script we'd be in big trouble here, I suspect.
+          var webShell = Components.classes["@mozilla.org/docshell;1"].createInstance();
+          webShell.QueryInterface(Components.interfaces.nsIBaseWindow).create();
           this.viewSourceProgressListener.webShell = webShell;
           var progress = webShell.QueryInterface(this.mnsIWebProgress);
           progress.addProgressListener(this.viewSourceProgressListener,
@@ -175,11 +179,12 @@ var gViewSourceUtils = {
     },
 
     destroy: function() {
-        this.webShell = null;
-        this.editor = null;
-        this.callBack = null;
-        this.data = null;
-        this.file = null;
+      this.webShell.QueryInterface(Components.interfaces.nsIBaseWindow).destroy();
+      this.webShell = null;
+      this.editor = null;
+      this.callBack = null;
+      this.data = null;
+      this.file = null;
     },
 
     onStateChange: function(aProgress, aRequest, aFlag, aStatus) {
